@@ -3,7 +3,7 @@ import json
 
 # Reads in machine_usage.dat
 def CollectData(data):
-    with open('/home/jan/public_html/machine_usage/machine_usage.dat') as file:
+    with open('/martini/sshuser/machine_usage/machine_usage.dat') as file:
         if data == 'log_date':
             time_stamp = int(next(file))
             log_date = datetime.fromtimestamp(time_stamp)
